Base annotation object definitions (sarpy.annotation.base)
==========================================================

.. automodule:: sarpy.annotation.base
    :members:
    :show-inheritance:
    :inherited-members:
